/*****************************************************************************
Copyright (c) 2011 SmartVault, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 ******************************************************************************/
package com.smartvault.net;

import java.util.*;
import java.util.Map.Entry;
import java.net.URLEncoder;

public final class QueryString
{
	private static final String AMP = "&"; //$NON-NLS-1$
	private static final String EQUAL = "="; //$NON-NLS-1$
	private static final String UTF_8 = "UTF-8"; //$NON-NLS-1$
	private String query = ""; //$NON-NLS-1$

	public QueryString()
	{
		// empty constructor
	}

	public QueryString(Map<String,String> h) throws Exception
	{
		Set<Map.Entry<String,String>> entries = h.entrySet();

		Iterator<Entry<String, String>> it = entries.iterator();

		while (it.hasNext()) 
		{
			Map.Entry<String,String> entry = it.next();
			put(entry.getKey(), entry.getValue());
		}
	}

	public void put(String name, String value) throws Exception
	{
		if (this.query.length() != 0) {
			this.query += AMP;
		}
		encode(name, value);
	}

	private void encode(String name, String value) throws Exception
	{
		this.query += URLEncoder.encode(name, UTF_8);
		this.query += EQUAL;
		this.query += URLEncoder.encode(value, UTF_8);
	}

	public String getQuery()
	{
		return this.query;
	}

	@Override
	public String toString()
	{
		return getQuery();
	}
}